## This library is free software; you can redistribute it and/or
## modify it under the terms of the GNU  General Public
## License as published by the Free Software Foundation; either
## version 2.0 of the License, or any later version.

## This library is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
##  General Public License for more details.

## You should have received a copy of the GNU  General Public
## License along with this library; if not, write to the Free Software
## Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

from __future__ import nested_scopes

from types import StringType, UnicodeType, StringTypes
from AccessControl import ClassSecurityInfo
from DateTime import DateTime
from Products.Archetypes.Registry import registerField
from Products.Archetypes.Registry import registerPropertyType
from Products.Archetypes.Field import ObjectField, Field, encode, decode
from Products.generator import i18n

from Products.DateBox import DateBoxWidget

STRING_TYPES = [StringType, UnicodeType]
"""String-types currently supported"""

_marker = []

__docformat__ = 'reStructuredText'

class DateBoxField(ObjectField):
    """A field that stores dates and times"""
    __implements__ = ObjectField.__implements__

    _properties = Field._properties.copy()
    _properties.update({
        'type' : 'datetime',
        'validators':('isDate',),
        'widget' : DateBoxWidget,
        })

    security = ClassSecurityInfo()
    
    security.declarePrivate('set')
    def set(self, instance, value, **kwargs):
        """
        Check if value is an actual date/time value. If not, attempt
        to convert it to one; otherwise, set to None. Assign all
        properties passed as kwargs to object.
        """
        if not value:
            value = None            
        elif not isinstance(value, DateTime):
            try:
                if type(value) == str:
                    value = value.replace('-','/')
                value = DateTime(value)
            except: #XXX bare exception
                value = None

        ObjectField.set(self, instance, value, **kwargs)


registerField(DateBoxField,
              title='DateBoxField',
              description=('Used for storing dates'))

registerPropertyType('default', 'datetime', DateBoxField)
